summaryrefslogtreecommitdiff
path: root/byterun/memory.h
diff options
context:
space:
mode:
authorDamien Doligez <damien.doligez-inria.fr>2004-01-02 19:23:29 +0000
committerDamien Doligez <damien.doligez-inria.fr>2004-01-02 19:23:29 +0000
commit0c7aecb88dc696f66f49f3bed54a037361a26b8d (patch)
tree32bde8a45b8881d3d121fd39cc1270980f596096 /byterun/memory.h
parent7ba8c1ca1d044232ed6d81d04a8c46800cf15097 (diff)
downloadocaml-0c7aecb88dc696f66f49f3bed54a037361a26b8d.tar.gz
depollution suite (et fin?) (PR#1914 et PR#1956)
git-svn-id: http://caml.inria.fr/svn/ocaml/trunk@6047 f963ae5c-01c2-4b8c-9fe0-0dff7051ff02
Diffstat (limited to 'byterun/memory.h')
-rw-r--r--byterun/memory.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/byterun/memory.h b/byterun/memory.h
index d73f49e136..f98e151521 100644
--- a/byterun/memory.h
+++ b/byterun/memory.h
@@ -363,16 +363,16 @@ CAMLextern struct caml__roots_block *caml_local_roots; /* defined in roots.c */
#define End_roots() caml_local_roots = caml__roots_block.next; }
-/* [register_global_root] registers a global C variable as a memory root
- for the duration of the program, or until [remove_global_root] is
+/* [caml_register_global_root] registers a global C variable as a memory root
+ for the duration of the program, or until [caml_remove_global_root] is
called. */
-CAMLextern void register_global_root (value *);
+CAMLextern void caml_register_global_root (value *);
-/* [remove_global_root] removes a memory root registered on a global C
- variable with [register_global_root]. */
+/* [caml_remove_global_root] removes a memory root registered on a global C
+ variable with [caml_register_global_root]. */
-CAMLextern void remove_global_root (value *);
+CAMLextern void caml_remove_global_root (value *);
#endif /* CAML_MEMORY_H */